<?php

namespace App\Classes\cPanel;

use App\Classes\cPanel\cPanelCore\cPanelCore;
use Exception;
use Illuminate\Support\Facades\Log;
use Throwable;

class cPanel
{
    protected ?cPanelCore $cPanelCore;
    protected bool $cPanelEnabled;

    /**
     * @throws Exception
     */
    public function __construct()
    {
        $this->cPanelEnabled = config('cPanel.enabled');
        $this->cPanelCore = null;

        try {
            if ($this->cPanelEnabled) {
                $this->cPanelCore = new cPanelCore(
                    config('cPanel.username'),
                    config('cPanel.password'),
                    config('cPanel.host'),
                    config('cPanel.port'),
                    config('cPanel.log')
                );
            }
        } catch (Throwable $e) {
            report($e);
        }
    }

    public function createSubdomain(
        string $domain,
        string $rootDomain,
        string $dir,
        int    $disallowDot = 1
    ): bool
    {
        try {
            $this->call(
                'SubDomain',
                'addsubdomain',
                [
                    'domain' => $domain,
                    'rootdomain' => $rootDomain,
                    'dir' => $dir,
                    'disallowdot' => $disallowDot
                ]
            );

            return true;
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }

    private function call(
        string $module,
        string $function,
        array  $params = [],
        string $api = 'uapi'
    ): void
    {
        if (!$this->cPanelEnabled) {
            Log::warning('cPanel is not enabled in the configuration file.');
            return;
        }

        try {
            $this->cPanelCore->execute($api, $module, $function, $params);
            return;
        } catch (Throwable $e) {
            report($e);
            return;
        }
    }

    public function deleteSubdomain(string $domain, string $rootDomain): bool
    {
        try {
            $this->call(
                'SubDomain',
                'delsubdomain',
                [
                    'domain' => $domain . '_' . $rootDomain
                ],
                'api2'
            );

            return true;
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }
}
