<?php

namespace App\Http\Controllers\BackOffice;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Services\CategoryService;
use Illuminate\Http\Request;

class CategoryController extends Controller
{
    public function __construct(protected CategoryService $categoryService)
    {
    }

    public function getSubcategories(Request $request)
    {
        $category = $this->categoryService->find($request->category_id);

        abort_if(is_null($category), 404);

        return response()->json([
            'status' => 'success',
            'data' => [
                'subcategories' => $category->subcategories
            ]
        ]);
    }

    public function index()
    {
        $categories = $this->categoryService->all();

        return view('backoffice.categories.index', compact('categories'));
    }

    public function create()
    {
        return view('backoffice.categories.create');
    }

    public function store(Request $request)
    {
        $category = $this->categoryService->store($request->label);

        $status = !is_null($category);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.categories.index') : null
            ]
        ]);
    }

    public function edit(Category $category)
    {
        $category->loadMissing(['subcategories']);

        return view('backoffice.categories.edit', compact('category'));
    }

    public function update(Request $request, Category $category)
    {
        $status = $this->categoryService->update($category, $request->label);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.categories.index') : null
            ]
        ]);
    }

    public function destroy(Category $category)
    {
        $status = $this->categoryService->delete($category);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.categories.index') : null
            ]
        ]);
    }
}
