<?php

namespace App\Http\Controllers\BackOffice;

use App\Http\Controllers\Controller;
use App\Models\Game;
use App\Services\CategoryService;
use App\Services\GameService;
use App\Services\SubcategoryService;
use Illuminate\Http\Request;
use Riftweb\Storage\Classes\RiftStorage;

class GameController extends Controller
{
    public function __construct(
        protected GameService        $gameService,
        protected CategoryService    $categoryService,
        protected SubcategoryService $subcategoryService
    )
    {
    }

    public function index()
    {
        $games = $this->gameService
            ->all();

        return view('backoffice.games.index', compact('games'));
    }

    public function create()
    {
        $categories = $this->categoryService->all();

        return view('backoffice.games.create', compact('categories'));
    }

    public function edit(Game $game)
    {
        $categories = $this->categoryService->all();

        return view('backoffice.games.edit', compact('game', 'categories'));
    }

    public function update(Request $request, Game $game)
    {
        $status = $this->gameService
            ->update(
                $game,
                $request->subdomain,
                $request->integer('rounds'),
                $this->categoryService->find($request->category_id),
                $this->subcategoryService->find($request->subcategory_id),
                $request->label,
                $request->description,
                RiftStorage::store($request->logo, 'games')?->path,
                RiftStorage::store($request->background, 'games')?->path,
                RiftStorage::store($request->sponsor_image, 'games')?->path,
                $request->sponsor,
                RiftStorage::store($request->about_us_image, 'games')?->path,
                $request->about_us,
                RiftStorage::store($request->prizes_image, 'games')?->path,
                $request->prizes,
                $request->boolean('status')
            );

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.games.index') : null
            ]
        ]);
    }

    public function store(Request $request)
    {
        $game = $this->gameService
            ->store(
                $request->subdomain,
                $request->integer('rounds'),
                $this->categoryService->find($request->category_id),
                $this->subcategoryService->find($request->subcategory_id),
                $request->label,
                $request->description,
                RiftStorage::store($request->logo, 'games')?->path,
                RiftStorage::store($request->background, 'games')?->path,
                RiftStorage::store($request->sponsor_image, 'games')?->path,
                $request->sponsor,
                RiftStorage::store($request->about_us_image, 'games')?->path,
                $request->about_us,
                RiftStorage::store($request->prizes_image, 'games')?->path,
                $request->prizes,
                $request->boolean('status')
            );

        $status = !is_null($game);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.games.index') : null
            ]
        ]);
    }

    public function destroy(Game $game)
    {
        $status = $this->gameService
            ->delete($game);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.games.index') : null
            ]
        ]);
    }
}
