<?php

namespace App\Http\Controllers\BackOffice;

use App\Http\Controllers\Controller;
use App\Models\Category;
use App\Models\Subcategory;
use App\Services\SubcategoryService;
use Illuminate\Http\Request;

class SubcategoryController extends Controller
{
    public function __construct(protected SubcategoryService $subcategoryService)
    {
    }

    public function create(Category $category)
    {
        return view('backoffice.subcategories.create', compact('category'));
    }

    public function store(Request $request, Category $category)
    {
        $subcategory = $this->subcategoryService->store(
            $category,
            $request->label
        );

        $status = !is_null($subcategory);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.categories.edit', ['category' => $category->id]) : null
            ]
        ]);
    }

    public function edit(Category $category, Subcategory $subcategory)
    {
        return view('backoffice.subcategories.edit', compact('category', 'subcategory'));
    }

    public function update(Request $request, Category $category, Subcategory $subcategory)
    {
        $status = $this->subcategoryService->update($subcategory, $request->label);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.categories.edit', ['category' => $category->id]) : null
            ]
        ]);
    }

    public function destroy(Category $category, Subcategory $subcategory)
    {
        $status = $this->subcategoryService->delete($subcategory);

        return response()->json([
            'status' => $status ? 'success' : 'error',
            'data' => [
                'redirect' => $status ? route('backoffice.categories.edit', ['category' => $category->id]) : null
            ]
        ]);
    }
}
