<?php

namespace App\Http\Middleware;

use Closure;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Lang;
use Throwable;

class LanguageMiddleware
{
    public function handle(Request $request, Closure $next)
    {
        $locale = Lang::getLocale();
        $cacheKey = "language.$locale";

        try {
            $languageArray = config('app.env') !== 'local' && cache()->has($cacheKey) ?
                cache()->get($cacheKey) :
                [];
        } catch (Throwable $e) {
            report($e);
            $languageArray = [];
        }

        if (empty($languageArray)) {
            $languageArray = collect(File::allFiles(lang_path($locale)))
                ->mapWithKeys(function ($file) {
                    return [$file->getFilenameWithoutExtension() => include $file->getPath() . '/' . $file->getFilename()];
                })->toArray();

            cache()->put($cacheKey, $languageArray);
        }

        view()->share(['jsTranslations' => $languageArray]);
        return $next($request);
    }
}
