<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Validation\Rule;

class AuthRequest extends FormRequest
{
    public function rules(): array
    {
        return [
            'bet_code' => [
                'required',
                'regex:/^[a-zA-Z\s]+\+[a-zA-Z\s]+\+\d{9}$/',
            ],
            'email' => [
                'required',
                Rule::unique('users', 'email')->where(function ($query) {
                    $query->where('bet_code', '!=', $this->input('bet_code'));
                }),
                'email'
            ]
        ];
    }

    public function messages(): array
    {
        $messages = parent::messages();
        $messages['bet_code'] = 'O bet code é inválido. Ex: Joana+Lisboa+192541987';
        $messages['email.unique'] = 'Este e-mail já se encontra registado.';

        return $messages;
    }

    public function authorize(): bool
    {
        return true;
    }
}
