<?php

namespace App\Repositories;


use App\Models\Category;
use Illuminate\Support\Collection;
use Throwable;

class CategoryRepository
{
    public function all(): Collection
    {
        try {
            return Category::all();
        } catch (Throwable $e) {
            report($e);
            return collect();
        }
    }

    public function find($id): ?Category
    {
        try {
            return Category::findOrFail($id);
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function store(string $label): ?Category
    {
        try {
            $data = [
                'label' => $label
            ];

            return Category::create($data);
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function update(
        Category $category,
        string   $label
    ): bool
    {
        try {
            $data = [
                'label' => $label
            ];

            return $category->update($data);
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }

    public function delete(Category $category): bool
    {
        try {
            return $category->delete();
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }
}
