<?php

namespace App\Repositories;


use App\Models\Category;
use App\Models\Game;
use App\Models\Subcategory;
use Illuminate\Support\Collection;
use Throwable;

class GameRepository
{
    public function all(): Collection
    {
        try {
            return Game::all();
        } catch (Throwable $e) {
            report($e);
            return collect();
        }
    }

    public function find($id): ?Game
    {
        try {
            return Game::findOrFail($id);
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function store(
        string      $subdomain,
        int         $rounds,
        Category    $category,
        Subcategory $subcategory,
        string      $label,
        string      $description,
        string      $logo,
        string      $background,
        ?string     $sponsorImage = null,
        ?string     $sponsor = null,
        ?string     $aboutUsImage = null,
        ?string     $aboutUs = null,
        ?string     $prizesImage = null,
        ?string     $prizes = null,
        bool        $status = true
    ): ?Game
    {
        try {
            $data = [
                'subdomain' => $subdomain,
                'rounds' => $rounds,
                'category_id' => $category->id,
                'subcategory_id' => $subcategory->id,
                'label' => $label,
                'description' => $description,
                'logo' => $logo,
                'background' => $background,
                'sponsor_image' => $sponsorImage,
                'sponsor' => $sponsor,
                'about_us_image' => $aboutUsImage,
                'about_us' => $aboutUs,
                'prizes_image' => $prizesImage,
                'prizes' => $prizes,
                'status' => $status,
            ];

            return Game::create($data);
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function update(
        Game        $game,
        string      $subdomain,
        int         $rounds,
        Category    $category,
        Subcategory $subcategory,
        string      $label,
        string      $description,
        ?string     $logo = null,
        ?string     $background = null,
        ?string     $sponsorImage = null,
        ?string     $sponsor = null,
        ?string     $aboutUsImage = null,
        ?string     $aboutUs = null,
        ?string     $prizesImage = null,
        ?string     $prizes = null,
        bool        $status = true
    ): bool
    {
        try {
            $data = [
                'subdomain' => $subdomain,
                'rounds' => $rounds,
                'category_id' => $category->id,
                'subcategory_id' => $subcategory->id,
                'label' => $label,
                'description' => $description,
                'logo' => $logo ?? $game->logo,
                'background' => $background ?? $game->background,
                'sponsor_image' => $sponsorImage ?? $game->sponsor_image,
                'sponsor' => $sponsor,
                'about_us_image' => $aboutUsImage ?? $game->about_us_image,
                'about_us' => $aboutUs,
                'prizes_image' => $prizesImage ?? $game->prizes_image,
                'prizes' => $prizes,
                'status' => $status,
            ];

            return $game->update($data);
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }

    public function delete(Game $game): bool
    {
        try {
            return $game->delete();
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }

    public function findBySubdomain(string $subdomain): ?Game
    {
        try {
            return Game::where('subdomain', $subdomain)->first();
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }
}
