<?php

namespace App\Repositories;


use App\Models\Category;
use App\Models\Subcategory;
use Illuminate\Support\Collection;
use Throwable;

class SubcategoryRepository
{
    public function all(): Collection
    {
        try {
            return Subcategory::all();
        } catch (Throwable $e) {
            report($e);
            return collect();
        }
    }

    public function find($id): ?Subcategory
    {
        try {
            return Subcategory::findOrFail($id);
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function store(
        Category $category,
        string   $label
    ): ?Subcategory
    {
        try {
            $data = [
                'category_id' => $category->id,
                'label' => $label
            ];

            return Subcategory::create($data);
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function update(
        Subcategory $subcategory,
        string      $label
    ): bool
    {
        try {
            $data = [
                'label' => $label
            ];

            return $subcategory->update($data);
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }

    public function delete(Subcategory $subcategory): bool
    {
        try {
            return $subcategory->delete();
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }
}
