<?php

namespace App\Repositories;

use App\Models\Game;
use App\Models\User;
use Carbon\Carbon;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Hash;
use Throwable;

class UserRepository
{
    public function store(Game $game, $name, $email, $betCode, $nif3, $city, $ip): ?User
    {
        try {
            $data = [
                'game_id' => $game->id,
                'twofactor' => rand(1000, 9999),
                'name' => $name,
                'email' => $email,
                'bet_code' => $betCode,
                'nif_3' => $nif3,
                'city' => $city,
                'ip' => $ip,
                'password' => Hash::make($betCode)
            ];

            return User::create($data);

        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function getByIp($ip): Collection
    {
        try {
            return User::where('ip', $ip)
                ->get();
        } catch (Throwable $e) {
            report($e);
            return collect();
        }
    }

    public function getByIpAndGame(Game $game, $ip): Collection
    {
        try {
            return User::where('ip', $ip)
                ->where('game_id', $game->id)
                ->get();
        } catch (Throwable $e) {
            report($e);
            return collect();
        }
    }

    public function findByBetCodeAndGame(Game $game, $betCode): ?User
    {
        try {
            return User::where('bet_code', $betCode)
                ->where('game_id', $game->id)
                ->first();
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function findByBetCode($betCode): ?User
    {
        try {
            return User::where('bet_code', $betCode)
                ->first();
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function findByNifAndGame(Game $game, string $nif3): ?User
    {
        try {
            return User::where('nif_3', $nif3)
                ->where('game_id', $game->id)
                ->first();
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function findByNif(string $nif3): ?User
    {
        try {
            return User::where('nif_3', $nif3)
                ->first();
        } catch (Throwable $e) {
            report($e);
            return null;
        }
    }

    public function massDelete(Collection $users): bool
    {
        try {
            return User::whereIn('id', $users->pluck('id')->toArray())
                ->delete();
        } catch (Throwable $e) {
            report($e);
            return false;
        }
    }

    public function getUnverifiedUsers(?Carbon $createdAtMax): Collection
    {
        try {
            return User::whereNull('email_verified_at')
                ->when(!is_null($createdAtMax), function ($query) use ($createdAtMax) {
                    $query->whereDate('created_at', '<=', $createdAtMax);
                })->get();
        } catch (Throwable $e) {
            report($e);
            return collect();
        }
    }
}
