<?php

namespace App\Services;


use App\Models\Category;
use App\Repositories\CategoryRepository;
use Illuminate\Support\Collection;

class CategoryService
{
    public function __construct(
        protected CategoryRepository $categoryRepository
    )
    {
    }

    public function all(): Collection
    {
        return $this->categoryRepository
            ->all();
    }

    public function find($id): ?Category
    {
        return $this->categoryRepository
            ->find($id);
    }

    public function store(
        string $label
    ): ?Category
    {
        return $this->categoryRepository
            ->store($label);
    }

    public function update(
        Category $category,
        string   $label
    ): bool
    {
        return $this->categoryRepository
            ->update(
                $category,
                $label
            );
    }

    public function delete(Category $category): bool
    {
        $subcategoryService = app(SubcategoryService::class);
        $category->subcategories->each(function ($subcategory) use ($subcategoryService) {
            $subcategoryService->delete($subcategory);
        });

        return $this->categoryRepository
            ->delete($category);
    }
}
