<?php

namespace App\Services;


use App\Classes\cPanel\cPanel;
use App\Models\Category;
use App\Models\Game;
use App\Models\Subcategory;
use App\Repositories\GameRepository;
use Illuminate\Support\Collection;

class GameService
{
    public function __construct(
        protected cPanel         $CPanel,
        protected GameRepository $gameRepository
    )
    {
    }

    public function all(): Collection
    {
        return $this->gameRepository
            ->all();
    }

    public function find($id): ?Game
    {
        return $this->gameRepository
            ->find($id);
    }

    public function findBySubdomain(string $subdomain): ?Game
    {
        return $this->gameRepository
            ->findBySubdomain($subdomain);
    }

    public function store(
        string      $subdomain,
        int         $rounds,
        Category    $category,
        Subcategory $subcategory,
        string      $label,
        string      $description,
        string      $logo,
        string      $background,
        ?string     $sponsorImage = null,
        ?string     $sponsor = null,
        ?string     $aboutUsImage = null,
        ?string     $aboutUs = null,
        ?string     $prizesImage = null,
        ?string     $prizes = null,
        bool        $status = true
    ): ?Game
    {
        $game = $this->gameRepository
            ->store(
                $subdomain,
                $rounds,
                $category,
                $subcategory,
                $label,
                $description,
                $logo,
                $background,
                $sponsorImage,
                $sponsor,
                $aboutUsImage,
                $aboutUs,
                $prizesImage,
                $prizes,
                $status
            );

        if (!is_null($game)) {
            $this->CPanel
                ->createSubdomain(
                    $subdomain,
                    config('cPanel.root_domain'),
                    config('cPanel.root_folder')
                );
        }

        return $game;
    }

    public function update(
        Game        $game,
        string      $subdomain,
        int         $rounds,
        Category    $category,
        Subcategory $subcategory,
        string      $label,
        string      $description,
        ?string     $logo = null,
        ?string     $background = null,
        ?string     $sponsorImage = null,
        ?string     $sponsor = null,
        ?string     $aboutUsImage = null,
        ?string     $aboutUs = null,
        ?string     $prizesImage = null,
        ?string     $prizes = null,
        bool        $status = true
    ): bool
    {
        $oldSubdomain = $game->subdomain;
        $status = $this->gameRepository
            ->update(
                $game,
                $subdomain,
                $rounds,
                $category,
                $subcategory,
                $label,
                $description,
                $logo,
                $background,
                $sponsorImage,
                $sponsor,
                $aboutUsImage,
                $aboutUs,
                $prizesImage,
                $prizes,
                $status
            );

        if ($status && $oldSubdomain !== $subdomain) {
            $this->CPanel
                ->deleteSubdomain(
                    $oldSubdomain,
                    config('cPanel.root_domain')
                );

            $this->CPanel
                ->createSubdomain(
                    $subdomain,
                    config('cPanel.root_domain'),
                    config('cPanel.root_folder')
                );
        }

        return $status;
    }

    public function delete(Game $game): bool
    {
        $subdomain = $game->subdomain;
        $status = $this->gameRepository->delete($game);

        if ($status) {
            $this->CPanel
                ->deleteSubdomain(
                    $subdomain,
                    config('cPanel.root_domain')
                );
        }

        return $status;
    }
}
