<?php

namespace App\Services;

use App\Models\FixPrize;
use Exception;
use Illuminate\Support\Collection;

class LottoService
{
    /**
     * @throws Exception
     */
    public function prize(Collection $orangeBalls, Collection $greenBalls, Collection $purpleBalls, string $action): array
    {
        $result = [
            'win' => true,
            'orange_take' => $orangeBalls,
            'green_take' => $greenBalls,
            'purple_take' => $purpleBalls,
            'orange_prize' => '',
            'green_prize' => '',
            'purple_prize' => '',
            'error' => false,
        ];

        $result = $this->getSetOfBallsWithPrize(
            $result,
            $orangeBalls,
            $greenBalls,
            $purpleBalls,
            $action
        );

        if ($result['error'] || $action === 'only-sort') {
            return $result;
        }

        $result['win'] =
            $this->checkPrizeWin($orangeBalls, $result['orange_prize']) &&
            $this->checkPrizeWin($greenBalls, $result['green_prize']) &&
            $this->checkPrizeWin($purpleBalls, $result['purple_prize']);

        return $result;
    }

    /**
     * @throws Exception
     */
    protected function getSetOfBallsWithPrize(
        array      $result,
        Collection $orangeBalls,
        Collection $greenBalls,
        Collection $purpleBalls,
        string     $action
    ): array
    {
        $totalBalls = $orangeBalls->count() + $greenBalls->count() + $purpleBalls->count();
        if ($action === 'fix-sort') {
            $prize = FixPrize::where('size', $totalBalls)->first();

            if (isset($prize)) {
                $result['orange_prize'] = collect($prize->orange_prize_draw);
                $result['green_prize'] = collect($prize->green_prize_draw);
                $result['purple_prize'] = collect($prize->purple_prize_draw);
            } else {
                $result['error'] = true;
                return $result;
            }
        } else {
            $randomBalls = $this->getRandomSetOfBalls($totalBalls);

            $result['orange_prize'] = collect($randomBalls->pop($orangeBalls->count()));
            $result['green_prize'] = collect($randomBalls->pop($greenBalls->count()));
            $result['purple_prize'] = collect($randomBalls->pop($purpleBalls->count()));
        }

        return [
            ...$result,
            'orange_prize' => $result['orange_prize']->sort(),
            'green_prize' => $result['green_prize']->sort(),
            'purple_prize' => $result['purple_prize']->sort()
        ];
    }

    /**
     * @throws Exception
     */
    protected function getRandomSetOfBalls($setSize): Collection
    {
        $randomBalls = collect();
        if ($setSize > 16) {
            throw new Exception('$setSize is bigger than the range of numbers');
        }

        for ($i = 0; $i < $setSize; $i++) {
            while (true) {
                $rand = rand(1, 16);
                if (!$randomBalls->contains($rand)) {
                    $randomBalls->push($rand);
                    break;
                }
            }
        }

        return $randomBalls;
    }

    protected function checkPrizeWin(Collection $selectedBalls, Collection $prizedBalls): bool
    {
        foreach ($selectedBalls as $selectedBall) {
            if (!$prizedBalls->contains($selectedBall)) {
                return false;
            }
        }
        return true;
    }
}
