<?php

namespace App\Services;

use App\Mail\TwoFactorMail;
use App\Models\Game;
use App\Models\User;
use App\Repositories\UserRepository;
use Carbon\Carbon;
use Illuminate\Support\Collection;
use Illuminate\Support\Facades\Mail;
use Throwable;

class UserService
{

    public function __construct(protected UserRepository $userRepository)
    {
    }

    public function store(Game $game, $name, $email, $betCode, $nif3, $city, $ip): ?User
    {
        return $this->userRepository
            ->store($game, $name, $email, $betCode, $nif3, $city, $ip);
    }

    public function sendTwoFactorAuthCode(User $user): void
    {
        try {
            Mail::to($user->email)->send(new TwoFactorMail($user));
        } catch (Throwable $e) {
            report($e);
        }
    }

    public function logoutAndClearSession(): void
    {
        session()->forget('two_factor');
        auth()->logout();
        session()->flush();
        session()->save();
    }

    public function getByIpAndGame(Game $game, $ip): Collection
    {
        return $this->userRepository
            ->getByIpAndGame($game, $ip);
    }

    public function getByIp($ip): Collection
    {
        return $this->userRepository
            ->getByIp($ip);
    }

    public function findByBetCodeAndGame(Game $game, $betCode): ?User
    {
        return $this->userRepository
            ->findByBetCodeAndGame($game, $betCode);
    }

    public function findByBetCode($betCode): ?User
    {
        return $this->userRepository
            ->findByBetCode($betCode);
    }

    public function setVerifiedAt(User $user): bool
    {
        return $user->markEmailAsVerified();
    }

    public function checkTwoFactor(User $user, $twofactor): bool
    {
        return (int)$user->twofactor === (int)$twofactor;
    }

    public function findByNifAndGame(Game $game, string $nif3): ?User
    {
        return $this->userRepository
            ->findByNifAndGame($game, $nif3);
    }

    public function findByNif(string $nif3): ?User
    {
        return $this->userRepository
            ->findByNif($nif3);
    }

    public function getUnverifiedUsers(?Carbon $createdAtMax): Collection
    {
        return $this->userRepository
            ->getUnverifiedUsers($createdAtMax);
    }

    public function massDelete(Collection $users): bool
    {
        return $this->userRepository
            ->massDelete($users);
    }
}
