@extends('layouts.backoffice.backoffice')

@section('title')
    Editar Categoria
@endsection

@section('content')
    <div class="container">
        <div class="card">
            <div class="card-body">
                <form class="ajax"
                      method="POST"
                      enctype="multipart/form-data"
                      action="{{ route('backoffice.categories.update', ['category' => $category->id]) }}"
                      data-action="patch"
                      data-type="categories">
                    @csrf
                    @method('PUT')
                    <div class="form-group mt-2">
                        <label for="label">Nome da Categoria</label>
                        <input required type="text" class="form-control" id="label" name="label"
                               placeholder="Nome da Categoria"
                               value="{{ $category->label }}">
                    </div>
                    <hr />
                    <div class="row mt-2">
                        <div class="col-12 text-right">
                            <a class="btn btn-danger" href="{{ route('backoffice.categories.index') }}">
                                <i class="fa-solid fa-chevron-left"></i>
                                Cancelar
                            </a>
                            @if($category->games->isNotEmpty())
                                <button type="button"
                                        class="btn btn-danger disabled ml-2"
                                        data-bs-toggle="tooltip"
                                        data-bs-title="Existem jogos associados a esta categoria"
                                        readonly>
                                    <i class="fa-solid fa-trash"></i>
                                    Eliminar
                                </button>
                            @else
                                <button type="button"
                                        class="btn btn-danger ml-2"
                                        onclick="document.getElementById('category-delete-form').submit()">
                                    <i class="fa-solid fa-trash"></i>
                                    Eliminar
                                </button>
                            @endif
                            <button type="submit" class="btn btn-primary ml-2">
                                <i class="fa-solid fa-save"></i>
                                Guardar
                            </button>
                        </div>
                    </div>
                </form>
            </div>
        </div>

        <div class="card mt-5">
            <div class="card-header">
                <h5 class="card-title fw-bold">Subcategorias</h5>
                <a class="btn btn-primary float-right"
                   href="{{ route('backoffice.subcategories.create', ['category' => $category->id]) }}">
                    <i class="fa-solid fa-plus"></i>
                    Nova Subcategoria
                </a>
            </div>
            <div class="card-body">
                <table class="table table-striped">
                    <thead>
                    <tr>
                        <th scope="col">Título</th>
                        <th scope="col">Data de Criação</th>
                        <th scope="col">Ações</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach ($category->subcategories as $subcategory)
                        <tr>
                            <td>{{ $subcategory->label }}</td>
                            <td>{{ $subcategory->created_at->format('d-m-Y H:i') }}</td>
                            <td>
                                <a class="btn btn-primary"
                                   href="{{ route('backoffice.subcategories.edit', ['category' => $category->id, 'subcategory' => $subcategory->id]) }}">
                                    <i class="fa-solid fa-pencil"></i>
                                </a>
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <form id="category-delete-form"
          class="ajax"
          action="{{ route('backoffice.categories.destroy', ['category' => $category->id]) }}"
          method="POST"
          data-action="delete"
          data-type="categories">
        @csrf
        @method('DELETE')
    </form>
@endsection

@section('js')
    <style>
        .disabled {
            pointer-events: initial !important;
            cursor:         not-allowed !important;
        }
    </style>
@endsection
