<?php

use App\Http\Controllers\AuthController;
use App\Http\Controllers\GameController;
use App\Http\Controllers\PrizeController;
use App\Http\Controllers\TwoFactorController;
use Illuminate\Support\Facades\Route;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

/* Redirect Home to Game Auth */
Route::get('', function () {
    return redirect()->route('login');
});

/* Auth Routes */
Route::get('login', function () {
    return redirect()->route('auth.index');
})->name('login');
Route::resource('auth', AuthController::class)->only(['index', 'store']);
Route::get('logout', [AuthController::class, 'logout'])->name('logout');


Route::group(['prefix' => 'api/user', 'middleware' => 'auth'], function () {
    Route::post('prize', [PrizeController::class, 'prize'])->name('api.user.prize.store');
    Route::post('prize/{userAction}/confirm', [PrizeController::class, 'confirmPrize'])->name('api.user.prize.confirm');
    Route::get('prize-list', [PrizeController::class, 'listPrize'])->withoutMiddleware(['auth'])->name('api.user.prize.list');
    Route::get('results', [PrizeController::class, 'showResults'])->name('api.user.results');
});

Route::resource('two-factor', TwoFactorController::class)->only(['index', 'store']);
Route::resource('games', GameController::class)->middleware(['auth', 'twoFactor'])->only(['index']);

